@@ -17,6 +17,7 @@ import aws_cdk.aws_iam
 import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
 import aws_cdk.aws_logs
+import aws_cdk.aws_sns
 import aws_cdk.aws_sqs
 import aws_cdk.core
 import constructs
@@ -78,6 +79,7 @@ class EdgeFunction(
         current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+        dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
@@ -119,8 +121,9 @@ class EdgeFunction(
         :param architectures: (deprecated) DEPRECATED. Default: [Architecture.X86_64]
         :param code_signing_config: Code signing config associated with this function. Default: - Not Sign the Code
         :param current_version_options: Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method. Default: - default options as described in ``VersionOptions``
-        :param dead_letter_queue: The SQS queue to use if DLQ is enabled. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
+        :param dead_letter_queue: The SQS queue to use if DLQ is enabled. If SNS topic is desired, specify ``deadLetterTopic`` property instead. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
         :param dead_letter_queue_enabled: Enabled DLQ. If ``deadLetterQueue`` is undefined, an SQS queue with default options will be defined for your Function. Default: - false unless ``deadLetterQueue`` is set, which implies DLQ is enabled.
+        :param dead_letter_topic: The SNS topic to use as a DLQ. Note that if ``deadLetterQueueEnabled`` is set to ``true``, an SQS queue will be created rather than an SNS topic. Using an SNS topic as a DLQ requires this property to be set explicitly. Default: - no SNS topic
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
@@ -162,6 +165,7 @@ class EdgeFunction(
             current_version_options=current_version_options,
             dead_letter_queue=dead_letter_queue,
             dead_letter_queue_enabled=dead_letter_queue_enabled,
+            dead_letter_topic=dead_letter_topic,
             description=description,
             environment=environment,
             environment_encryption=environment_encryption,
@@ -391,8 +395,6 @@ class EdgeFunction(
     ) -> aws_cdk.aws_cloudwatch.Metric:
         '''Return the given named metric for this Lambda Return the given named metric for this Function.
 
-        Return the given named metric for this Lambda Return the given named metric for this Function.
-
         :param metric_name: -
         :param account: Account which this metric comes from. Default: - Deployment account.
         :param color: The hex color code, prefixed with '#' (e.g. '#00ff00'), to use when this metric is rendered on a graph. The ``Color`` class has a set of standard colors that can be used here. Default: - Automatic color
@@ -434,9 +436,6 @@ class EdgeFunction(
     ) -> aws_cdk.aws_cloudwatch.Metric:
         '''Metric for the Duration of this Lambda How long execution of this Lambda takes.
 
-        Average over 5 minutes
-        Metric for the Duration of this Lambda How long execution of this Lambda takes.
-
         Average over 5 minutes
 
         :param account: Account which this metric comes from. Default: - Deployment account.
@@ -521,9 +520,6 @@ class EdgeFunction(
     ) -> aws_cdk.aws_cloudwatch.Metric:
         '''Metric for the number of invocations of this Lambda How often this Lambda is invoked.
 
-        Sum over 5 minutes
-        Metric for the number of invocations of this Lambda How often this Lambda is invoked.
-
         Sum over 5 minutes
 
         :param account: Account which this metric comes from. Default: - Deployment account.
@@ -566,9 +562,6 @@ class EdgeFunction(
     ) -> aws_cdk.aws_cloudwatch.Metric:
         '''Metric for the number of throttled invocations of this Lambda How often this Lambda is throttled.
 
-        Sum over 5 minutes
-        Metric for the number of throttled invocations of this Lambda How often this Lambda is throttled.
-
         Sum over 5 minutes
 
         :param account: Account which this metric comes from. Default: - Deployment account.
@@ -704,6 +697,7 @@ class EdgeFunction(
         "current_version_options": "currentVersionOptions",
         "dead_letter_queue": "deadLetterQueue",
         "dead_letter_queue_enabled": "deadLetterQueueEnabled",
+        "dead_letter_topic": "deadLetterTopic",
         "description": "description",
         "environment": "environment",
         "environment_encryption": "environmentEncryption",
@@ -749,6 +743,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         current_version_options: typing.Optional[aws_cdk.aws_lambda.VersionOptions] = None,
         dead_letter_queue: typing.Optional[aws_cdk.aws_sqs.IQueue] = None,
         dead_letter_queue_enabled: typing.Optional[builtins.bool] = None,
+        dead_letter_topic: typing.Optional[aws_cdk.aws_sns.ITopic] = None,
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
@@ -789,8 +784,9 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         :param architectures: (deprecated) DEPRECATED. Default: [Architecture.X86_64]
         :param code_signing_config: Code signing config associated with this function. Default: - Not Sign the Code
         :param current_version_options: Options for the ``lambda.Version`` resource automatically created by the ``fn.currentVersion`` method. Default: - default options as described in ``VersionOptions``
-        :param dead_letter_queue: The SQS queue to use if DLQ is enabled. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
+        :param dead_letter_queue: The SQS queue to use if DLQ is enabled. If SNS topic is desired, specify ``deadLetterTopic`` property instead. Default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
         :param dead_letter_queue_enabled: Enabled DLQ. If ``deadLetterQueue`` is undefined, an SQS queue with default options will be defined for your Function. Default: - false unless ``deadLetterQueue`` is set, which implies DLQ is enabled.
+        :param dead_letter_topic: The SNS topic to use as a DLQ. Note that if ``deadLetterQueueEnabled`` is set to ``true``, an SQS queue will be created rather than an SNS topic. Using an SNS topic as a DLQ requires this property to be set explicitly. Default: - no SNS topic
         :param description: A description of the function. Default: - No description.
         :param environment: Key-value pairs that Lambda caches and makes available for your Lambda functions. Use environment variables to apply configuration changes, such as test and production environment configurations, without changing your Lambda function source code. Default: - No environment variables.
         :param environment_encryption: The AWS KMS key that's used to encrypt your function's environment variables. Default: - AWS Lambda creates and uses an AWS managed customer master key (CMK).
@@ -877,6 +873,8 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
             self._values["dead_letter_queue"] = dead_letter_queue
         if dead_letter_queue_enabled is not None:
             self._values["dead_letter_queue_enabled"] = dead_letter_queue_enabled
+        if dead_letter_topic is not None:
+            self._values["dead_letter_topic"] = dead_letter_topic
         if description is not None:
             self._values["description"] = description
         if environment is not None:
@@ -1043,6 +1041,8 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
     def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.IQueue]:
         '''The SQS queue to use if DLQ is enabled.
 
+        If SNS topic is desired, specify ``deadLetterTopic`` property instead.
+
         :default: - SQS queue with 14 day retention period if ``deadLetterQueueEnabled`` is ``true``
         '''
         result = self._values.get("dead_letter_queue")
@@ -1060,6 +1060,18 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         result = self._values.get("dead_letter_queue_enabled")
         return typing.cast(typing.Optional[builtins.bool], result)
 
+    @builtins.property
+    def dead_letter_topic(self) -> typing.Optional[aws_cdk.aws_sns.ITopic]:
+        '''The SNS topic to use as a DLQ.
+
+        Note that if ``deadLetterQueueEnabled`` is set to ``true``, an SQS queue will be created
+        rather than an SNS topic. Using an SNS topic as a DLQ requires this property to be set explicitly.
+
+        :default: - no SNS topic
+        '''
+        result = self._values.get("dead_letter_topic")
+        return typing.cast(typing.Optional[aws_cdk.aws_sns.ITopic], result)
+
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
         '''A description of the function.
